@@ -2,7 +2,7 @@ from django.conf import settings
 from django.conf.urls import patterns, url
 from django.conf.urls.static import static
 
-from django_master.views import HomeView
+from django_master.views.home import HomeView
 from django_master.views.routes import RoutesListView
 from django_master.views.settings import SettingsListView
 
@@ -17,10 +17,6 @@ urlpatterns = patterns(r'',
     url(r'^settings/$', SettingsListView.as_view(),
         name='djangomaster_settings'),
 
-
-    url(r'^tudo/(\d+)/(\d+)$', HomeView.as_view(), name='djangomaster_tudo'),
-    url(r'^nada/(?P<nada>\w+)$', HomeView.as_view(), name='djangomaster_nada'),
-
 )
 
 if STATIC_ACTIVATED:
